==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/JobActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.JobActionArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.JobActionType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property errorAction Gets or sets the error action.
 * @property queueMessage Gets or sets the storage queue message.
 * @property request Gets or sets the http requests.
 * @property retryPolicy Gets or sets the retry policy.
 * @property serviceBusQueueMessage Gets or sets the service bus queue message.
 * @property serviceBusTopicMessage Gets or sets the service bus topic message.
 * @property type Gets or sets the job action type.
 */
public data class JobActionArgs(
    public val errorAction: Output<JobErrorActionArgs>? = null,
    public val queueMessage: Output<StorageQueueMessageArgs>? = null,
    public val request: Output<HttpRequestArgs>? = null,
    public val retryPolicy: Output<RetryPolicyArgs>? = null,
    public val serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null,
    public val serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null,
    public val type: Output<JobActionType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.JobActionArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.JobActionArgs =
        com.pulumi.azurenative.scheduler.inputs.JobActionArgs.builder()
            .errorAction(errorAction?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .queueMessage(queueMessage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .request(request?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retryPolicy(retryPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .serviceBusQueueMessage(
                serviceBusQueueMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .serviceBusTopicMessage(
                serviceBusTopicMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .type(type?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [JobActionArgs].
 */
@PulumiTagMarker
public class JobActionArgsBuilder internal constructor() {
    private var errorAction: Output<JobErrorActionArgs>? = null

    private var queueMessage: Output<StorageQueueMessageArgs>? = null

    private var request: Output<HttpRequestArgs>? = null

    private var retryPolicy: Output<RetryPolicyArgs>? = null

    private var serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null

    private var serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null

    private var type: Output<JobActionType>? = null

    /**
     * @param value Gets or sets the error action.
     */
    @JvmName("omyillpcygsftxds")
    public suspend fun errorAction(`value`: Output<JobErrorActionArgs>) {
        this.errorAction = value
    }

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("wlaodmkkjjenxfvc")
    public suspend fun queueMessage(`value`: Output<StorageQueueMessageArgs>) {
        this.queueMessage = value
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("sevqmjypelnhjrhx")
    public suspend fun request(`value`: Output<HttpRequestArgs>) {
        this.request = value
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("iqbgyygrhgwtfxhg")
    public suspend fun retryPolicy(`value`: Output<RetryPolicyArgs>) {
        this.retryPolicy = value
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("clvnubhifmjiwrlc")
    public suspend fun serviceBusQueueMessage(`value`: Output<ServiceBusQueueMessageArgs>) {
        this.serviceBusQueueMessage = value
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("mroxwvwjqwvqvhmv")
    public suspend fun serviceBusTopicMessage(`value`: Output<ServiceBusTopicMessageArgs>) {
        this.serviceBusTopicMessage = value
    }

    /**
     * @param value Gets or sets the job action type.
     */
    @JvmName("evntjtopnuajgfvc")
    public suspend fun type(`value`: Output<JobActionType>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the error action.
     */
    @JvmName("nvbkjiswmptwtdft")
    public suspend fun errorAction(`value`: JobErrorActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.errorAction = mapped
    }

    /**
     * @param argument Gets or sets the error action.
     */
    @JvmName("pcdnjvhmfpaduolg")
    public suspend fun errorAction(argument: suspend JobErrorActionArgsBuilder.() -> Unit) {
        val toBeMapped = JobErrorActionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.errorAction = mapped
    }

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("fgaodohoeflcdnej")
    public suspend fun queueMessage(`value`: StorageQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queueMessage = mapped
    }

    /**
     * @param argument Gets or sets the storage queue message.
     */
    @JvmName("gbtfbxyqxpmwodyc")
    public suspend fun queueMessage(argument: suspend StorageQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = StorageQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.queueMessage = mapped
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("yntrrabjmunowcsv")
    public suspend fun request(`value`: HttpRequestArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.request = mapped
    }

    /**
     * @param argument Gets or sets the http requests.
     */
    @JvmName("pesqqrimyiorsbrb")
    public suspend fun request(argument: suspend HttpRequestArgsBuilder.() -> Unit) {
        val toBeMapped = HttpRequestArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.request = mapped
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("prehhdthxnkyqued")
    public suspend fun retryPolicy(`value`: RetryPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retryPolicy = mapped
    }

    /**
     * @param argument Gets or sets the retry policy.
     */
    @JvmName("gnbeeehypkegbvny")
    public suspend fun retryPolicy(argument: suspend RetryPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetryPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retryPolicy = mapped
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("qfaodtcywdahcwmg")
    public suspend fun serviceBusQueueMessage(`value`: ServiceBusQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus queue message.
     */
    @JvmName("eepeforpkcwooxdp")
    public suspend
    fun serviceBusQueueMessage(argument: suspend ServiceBusQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("jtkilckvwdlompax")
    public suspend fun serviceBusTopicMessage(`value`: ServiceBusTopicMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus topic message.
     */
    @JvmName("opugrmqnyiifryrd")
    public suspend
    fun serviceBusTopicMessage(argument: suspend ServiceBusTopicMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusTopicMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param value Gets or sets the job action type.
     */
    @JvmName("ptldhvqtkrbgbysq")
    public suspend fun type(`value`: JobActionType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JobActionArgs = JobActionArgs(
        errorAction = errorAction,
        queueMessage = queueMessage,
        request = request,
        retryPolicy = retryPolicy,
        serviceBusQueueMessage = serviceBusQueueMessage,
        serviceBusTopicMessage = serviceBusTopicMessage,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/JobActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.JobActionArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.JobActionType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property errorAction Gets or sets the error action.
 * @property queueMessage Gets or sets the storage queue message.
 * @property request Gets or sets the http requests.
 * @property retryPolicy Gets or sets the retry policy.
 * @property serviceBusQueueMessage Gets or sets the service bus queue message.
 * @property serviceBusTopicMessage Gets or sets the service bus topic message.
 * @property type Gets or sets the job action type.
 */
public data class JobActionArgs(
    public val errorAction: Output<JobErrorActionArgs>? = null,
    public val queueMessage: Output<StorageQueueMessageArgs>? = null,
    public val request: Output<HttpRequestArgs>? = null,
    public val retryPolicy: Output<RetryPolicyArgs>? = null,
    public val serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null,
    public val serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null,
    public val type: Output<JobActionType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.JobActionArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.JobActionArgs =
        com.pulumi.azurenative.scheduler.inputs.JobActionArgs.builder()
            .errorAction(errorAction?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .queueMessage(queueMessage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .request(request?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retryPolicy(retryPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .serviceBusQueueMessage(
                serviceBusQueueMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .serviceBusTopicMessage(
                serviceBusTopicMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .type(type?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [JobActionArgs].
 */
@PulumiTagMarker
public class JobActionArgsBuilder internal constructor() {
    private var errorAction: Output<JobErrorActionArgs>? = null

    private var queueMessage: Output<StorageQueueMessageArgs>? = null

    private var request: Output<HttpRequestArgs>? = null

    private var retryPolicy: Output<RetryPolicyArgs>? = null

    private var serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null

    private var serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null

    private var type: Output<JobActionType>? = null

    /**
     * @param value Gets or sets the error action.
     */
    @JvmName("akslhmuewcxldwaj")
    public suspend fun errorAction(`value`: Output<JobErrorActionArgs>) {
        this.errorAction = value
    }

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("nbgpjjftcirtdvog")
    public suspend fun queueMessage(`value`: Output<StorageQueueMessageArgs>) {
        this.queueMessage = value
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("ylcnhcdfmhkpggil")
    public suspend fun request(`value`: Output<HttpRequestArgs>) {
        this.request = value
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("bexhcqkbmikhcmhw")
    public suspend fun retryPolicy(`value`: Output<RetryPolicyArgs>) {
        this.retryPolicy = value
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("ggivftbqklgibhgh")
    public suspend fun serviceBusQueueMessage(`value`: Output<ServiceBusQueueMessageArgs>) {
        this.serviceBusQueueMessage = value
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("apfhcvrenxpobfbg")
    public suspend fun serviceBusTopicMessage(`value`: Output<ServiceBusTopicMessageArgs>) {
        this.serviceBusTopicMessage = value
    }

    /**
     * @param value Gets or sets the job action type.
     */
    @JvmName("ypkravjojiqhmodb")
    public suspend fun type(`value`: Output<JobActionType>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the error action.
     */
    @JvmName("gjkhmwfqmlspvpym")
    public suspend fun errorAction(`value`: JobErrorActionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.errorAction = mapped
    }

    /**
     * @param argument Gets or sets the error action.
     */
    @JvmName("tnqrqswyvfyghulf")
    public suspend fun errorAction(argument: suspend JobErrorActionArgsBuilder.() -> Unit) {
        val toBeMapped = JobErrorActionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.errorAction = mapped
    }

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("gipvwedjrhhdykfj")
    public suspend fun queueMessage(`value`: StorageQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queueMessage = mapped
    }

    /**
     * @param argument Gets or sets the storage queue message.
     */
    @JvmName("pjtdtegpwwnutvhb")
    public suspend fun queueMessage(argument: suspend StorageQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = StorageQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.queueMessage = mapped
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("xerfbipwvldwbejv")
    public suspend fun request(`value`: HttpRequestArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.request = mapped
    }

    /**
     * @param argument Gets or sets the http requests.
     */
    @JvmName("ogpfpuqtishbcicj")
    public suspend fun request(argument: suspend HttpRequestArgsBuilder.() -> Unit) {
        val toBeMapped = HttpRequestArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.request = mapped
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("wmggfvhqlojsaupb")
    public suspend fun retryPolicy(`value`: RetryPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retryPolicy = mapped
    }

    /**
     * @param argument Gets or sets the retry policy.
     */
    @JvmName("scwirldwmjqwggiu")
    public suspend fun retryPolicy(argument: suspend RetryPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetryPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retryPolicy = mapped
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("onrcancyqkotgdxp")
    public suspend fun serviceBusQueueMessage(`value`: ServiceBusQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus queue message.
     */
    @JvmName("rpcfiputqyubekqd")
    public suspend
    fun serviceBusQueueMessage(argument: suspend ServiceBusQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("ijgqfgxaeqcocusm")
    public suspend fun serviceBusTopicMessage(`value`: ServiceBusTopicMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus topic message.
     */
    @JvmName("vbwibocxbmxyudmf")
    public suspend
    fun serviceBusTopicMessage(argument: suspend ServiceBusTopicMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusTopicMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param value Gets or sets the job action type.
     */
    @JvmName("wkkbcoulmksuliba")
    public suspend fun type(`value`: JobActionType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JobActionArgs = JobActionArgs(
        errorAction = errorAction,
        queueMessage = queueMessage,
        request = request,
        retryPolicy = retryPolicy,
        serviceBusQueueMessage = serviceBusQueueMessage,
        serviceBusTopicMessage = serviceBusTopicMessage,
        type = type,
    )
}
